@@ -3,6 +3,7 @@
 namespace Doctrine\Bundle\DoctrineBundle\Tests\DataCollector;
 
 use Doctrine\Bundle\DoctrineBundle\DataCollector\DoctrineDataCollector;
+use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Mapping\ClassMetadataInfo;
 use PHPUnit\Framework\TestCase;
 use ReflectionClass;
@@ -16,9 +17,13 @@ class DoctrineDataCollectorTest extends TestCase
 
     public function testCollectEntities() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $manager   = $this->getMockBuilder('Doctrine\ORM\EntityManager')->disableOriginalConstructor()->getMock();
         $config    = $this->getMockBuilder('Doctrine\ORM\Configuration')->getMock();
-        $factory   = $this->getMockBuilder('Doctrine\Common\Persistence\Mapping\AbstractClassMetadataFactory')
+        $factory   = $this->getMockBuilder('Doctrine\Persistence\Mapping\AbstractClassMetadataFactory')
             ->setMethods(['getLoadedMetadata'])->getMockForAbstractClass();
         $collector = $this->createCollector(['default' => $manager]);
 
@@ -49,6 +54,27 @@ class DoctrineDataCollectorTest extends TestCase
         $this->assertCount(2, $entities['default']);
     }
 
+    public function testDoesNotCollectEntities() : void
+    {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
+        $manager   = $this->createMock('Doctrine\ORM\EntityManager');
+        $config    = $this->createMock('Doctrine\ORM\Configuration');
+        $collector = $this->createCollector(['default' => $manager], false);
+
+        $manager->expects($this->never())
+            ->method('getMetadataFactory');
+        $manager->method('getConfiguration')
+            ->will($this->returnValue($config));
+
+        $collector->collect(new Request(), new Response());
+
+        $this->assertEmpty($collector->getMappingErrors());
+        $this->assertEmpty($collector->getEntities());
+    }
+
     public function testGetGroupedQueries() : void
     {
         $logger            = $this->getMockBuilder('Doctrine\DBAL\Logging\DebugStack')->getMock();
@@ -95,7 +121,7 @@ class DoctrineDataCollectorTest extends TestCase
         return $metadata;
     }
 
-    private function createCollector(array $managers) : DoctrineDataCollector
+    private function createCollector(array $managers, bool $shouldValidateSchema = true) : DoctrineDataCollector
     {
         $registry = $this->getMockBuilder('Doctrine\Persistence\ManagerRegistry')->getMock();
         $registry
@@ -111,6 +137,6 @@ class DoctrineDataCollectorTest extends TestCase
             ->method('getManagers')
             ->will($this->returnValue($managers));
 
-        return new DoctrineDataCollector($registry);
+        return new DoctrineDataCollector($registry, $shouldValidateSchema);
     }
 }
