@@ -28,6 +28,10 @@ class DoctrineExtensionTest extends TestCase
      */
     public function testAutowiringAlias() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer();
         $extension = new DoctrineExtension();
         $config    = BundleConfigurationBuilder::createBuilderWithBaseValues()->build();
@@ -51,6 +55,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testPublicServicesAndAliases() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer();
         $extension = new DoctrineExtension();
         $config    = BundleConfigurationBuilder::createBuilderWithBaseValues()->build();
@@ -102,6 +110,10 @@ class DoctrineExtensionTest extends TestCase
      */
     public function testOrmRequiresDbal() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $extension = new DoctrineExtension();
 
         $extension->load([['orm' => ['auto_mapping' => true]]], $this->getContainer());
@@ -147,6 +159,10 @@ class DoctrineExtensionTest extends TestCase
      */
     public function testAutomapping(array $entityManagers) : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $extension = new DoctrineExtension();
 
         $container = $this->getContainer([
@@ -240,6 +256,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testDependencyInjectionConfigurationDefaults() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer();
         $extension = new DoctrineExtension();
         $config    = BundleConfigurationBuilder::createBuilderWithBaseValues()->build();
@@ -257,7 +277,7 @@ class DoctrineExtensionTest extends TestCase
         $this->assertEquals('11211', $container->getParameter('doctrine.orm.cache.memcache_port'));
         $this->assertEquals('Memcache', $container->getParameter('doctrine.orm.cache.memcache_instance.class'));
         $this->assertEquals('Doctrine\Common\Cache\XcacheCache', $container->getParameter('doctrine.orm.cache.xcache.class'));
-        $this->assertEquals('Doctrine\Common\Persistence\Mapping\Driver\MappingDriverChain', $container->getParameter('doctrine.orm.metadata.driver_chain.class'));
+        $this->assertEquals('Doctrine\Persistence\Mapping\Driver\MappingDriverChain', $container->getParameter('doctrine.orm.metadata.driver_chain.class'));
         $this->assertEquals('Doctrine\ORM\Mapping\Driver\AnnotationDriver', $container->getParameter('doctrine.orm.metadata.annotation.class'));
         $this->assertEquals('Doctrine\ORM\Mapping\Driver\SimplifiedXmlDriver', $container->getParameter('doctrine.orm.metadata.xml.class'));
         $this->assertEquals('Doctrine\ORM\Mapping\Driver\SimplifiedYamlDriver', $container->getParameter('doctrine.orm.metadata.yml.class'));
@@ -350,13 +370,14 @@ class DoctrineExtensionTest extends TestCase
         $container = $this->getContainer();
         $extension = new DoctrineExtension();
 
-        $extension->load([[
-            'dbal' => [
-                'connections' => [
-                    'default' => ['password' => 'foo', 'use_savepoints' => true],
+        $extension->load([
+            [
+                'dbal' => [
+                    'connections' => [
+                        'default' => ['password' => 'foo', 'use_savepoints' => true],
+                    ],
                 ],
             ],
-        ],
         ], $container);
 
         $calls = $container->getDefinition('doctrine.dbal.default_connection')->getMethodCalls();
@@ -367,6 +388,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testAutoGenerateProxyClasses() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer();
         $extension = new DoctrineExtension();
 
@@ -391,6 +416,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testSingleEntityManagerWithDefaultConfiguration() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer();
         $extension = new DoctrineExtension();
 
@@ -411,6 +440,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testSingleEntityManagerWithDefaultSecondLevelCacheConfiguration() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer();
         $extension = new DoctrineExtension();
 
@@ -436,6 +469,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testSingleEntityManagerWithCustomSecondLevelCacheConfiguration() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer();
         $extension = new DoctrineExtension();
 
@@ -467,6 +504,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testBundleEntityAliases() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer();
         $extension = new DoctrineExtension();
 
@@ -486,6 +527,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testOverwriteEntityAliases() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer();
         $extension = new DoctrineExtension();
 
@@ -505,6 +550,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testYamlBundleMappingDetection() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer('YamlBundle');
         $extension = new DoctrineExtension();
 
@@ -523,6 +572,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testXmlBundleMappingDetection() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer('XmlBundle');
         $extension = new DoctrineExtension();
 
@@ -550,6 +603,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testAnnotationsBundleMappingDetection() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer('AnnotationsBundle');
         $extension = new DoctrineExtension();
 
@@ -577,6 +634,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testOrmMergeConfigs() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer(['XmlBundle', 'AnnotationsBundle']);
         $extension = new DoctrineExtension();
 
@@ -634,6 +695,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testAnnotationsBundleMappingDetectionWithVendorNamespace() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer('AnnotationsBundle', 'Vendor');
         $extension = new DoctrineExtension();
 
@@ -688,6 +753,10 @@ class DoctrineExtensionTest extends TestCase
 
     public function testInvalidCacheConfiguration() : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer();
         $extension = new DoctrineExtension();
 
@@ -709,6 +778,10 @@ class DoctrineExtensionTest extends TestCase
      */
     public function testCacheConfiguration(string $expectedAliasName, string $expectedAliasTarget, string $cacheName, $cacheConfig) : void
     {
+        if (! interface_exists(EntityManagerInterface::class)) {
+            self::markTestSkipped('This test requires ORM');
+        }
+
         $container = $this->getContainer();
         $extension = new DoctrineExtension();
 
