@@ -5,6 +5,7 @@ namespace Doctrine\Bundle\DoctrineBundle\Tests;
 use Doctrine\Bundle\DoctrineBundle\DependencyInjection\Compiler\ServiceRepositoryCompilerPass;
 use Doctrine\Bundle\DoctrineBundle\DependencyInjection\DoctrineExtension;
 use Doctrine\Common\Annotations\AnnotationReader;
+use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\EntityRepository;
 use Doctrine\ORM\QueryBuilder;
 use Fixtures\Bundles\RepositoryServiceBundle\Entity\TestCustomClassRepoEntity;
@@ -20,6 +21,15 @@ use Symfony\Component\DependencyInjection\ParameterBag\ParameterBag;
 
 class ServiceRepositoryTest extends TestCase
 {
+    public static function setUpBeforeClass() : void
+    {
+        if (interface_exists(EntityManagerInterface::class)) {
+            return;
+        }
+
+        self::markTestSkipped('This test requires ORM');
+    }
+
     /**
      * https://github.com/doctrine/orm/pull/7953 needed, otherwise ORM classes we define services for trigger deprecations
      *
@@ -50,21 +60,22 @@ class ServiceRepositoryTest extends TestCase
 
         $extension = new DoctrineExtension();
         $container->registerExtension($extension);
-        $extension->load([[
-            'dbal' => [
-                'driver' => 'pdo_sqlite',
-                'charset' => 'UTF8',
-            ],
-            'orm' => [
-                'mappings' => [
-                    'RepositoryServiceBundle' => [
-                        'type' => 'annotation',
-                        'dir' => __DIR__ . '/DependencyInjection/Fixtures/Bundles/RepositoryServiceBundle/Entity',
-                        'prefix' => 'Fixtures\Bundles\RepositoryServiceBundle\Entity',
+        $extension->load([
+            [
+                'dbal' => [
+                    'driver' => 'pdo_sqlite',
+                    'charset' => 'UTF8',
+                ],
+                'orm' => [
+                    'mappings' => [
+                        'RepositoryServiceBundle' => [
+                            'type' => 'annotation',
+                            'dir' => __DIR__ . '/DependencyInjection/Fixtures/Bundles/RepositoryServiceBundle/Entity',
+                            'prefix' => 'Fixtures\Bundles\RepositoryServiceBundle\Entity',
+                        ],
                     ],
                 ],
             ],
-        ],
         ], $container);
 
         $def = $container->register(TestCustomServiceRepoRepository::class, TestCustomServiceRepoRepository::class)
