@@ -56,6 +56,18 @@ class DoctrineExtensionTest extends TestCase
         $this->assertEquals('a=1 OR b=2', $result);
     }
 
+    public function testReplaceQueryParametersWithEmptyArray() : void
+    {
+        $extension  = new DoctrineExtension();
+        $query      = 'IN (?)';
+        $parameters = [
+            [],
+        ];
+
+        $result = $extension->replaceQueryParameters($query, $parameters);
+        $this->assertEquals('IN (NULL)', $result);
+    }
+
     public function testEscapeBinaryParameter() : void
     {
         $binaryString = pack('H*', '9d40b8c1417f42d099af4782ec4b20b6');
@@ -69,7 +81,7 @@ class DoctrineExtensionTest extends TestCase
 
     public function testEscapeArrayParameter() : void
     {
-        $this->assertEquals("1, NULL, 'test', foo", DoctrineExtension::escapeFunction([1, null, 'test', new DummyClass('foo')]));
+        $this->assertEquals("1, NULL, 'test', foo, NULL", DoctrineExtension::escapeFunction([1, null, 'test', new DummyClass('foo'), []]));
     }
 
     public function testEscapeObjectParameter() : void
@@ -87,6 +99,63 @@ class DoctrineExtensionTest extends TestCase
     {
         $this->assertEquals('1', DoctrineExtension::escapeFunction(true));
     }
+
+    /**
+     * @group legacy
+     */
+    public function testItHighlightsSqlQueriesUsingCssClasses() : void
+    {
+        $extension = new DoctrineExtension();
+        self::assertStringContainsString(
+            'class=',
+            $extension->formatQuery('CREATE DATABASE 📚;')
+        );
+        self::assertStringContainsString(
+            'class=',
+            $extension->formatSql('CREATE DATABASE 📚;', true)
+        );
+    }
+
+    /**
+     * @group legacy
+     */
+    public function testItDoesNotOutputDuplicatePreTags() : void
+    {
+        $extension = new DoctrineExtension();
+        self::assertSame(
+            1,
+            substr_count($extension->formatQuery('CREATE DATABASE 📚;'), '<pre')
+        );
+        self::assertSame(
+            1,
+            substr_count($extension->formatSQL('CREATE DATABASE 📚;', true), '<pre')
+        );
+    }
+
+    /**
+     * @group legacy
+     */
+    public function testItUsesCssOnTheDivTag() : void
+    {
+        $extension = new DoctrineExtension();
+        self::assertSame(
+            1,
+            substr_count($extension->formatQuery('CREATE DATABASE 📚;'), '<div class=')
+        );
+        self::assertSame(
+            1,
+            substr_count($extension->formatQuery('CREATE DATABASE 📚;'), '<pre>')
+        );
+    }
+
+    public function testItUsesCssOnThePreTag() : void
+    {
+        $extension = new DoctrineExtension();
+        self::assertSame(
+            1,
+            substr_count($extension->formatSQL('CREATE DATABASE 📚;', true), '<pre class=')
+        );
+    }
 }
 
 class DummyClass
